==> c%2B%2Butilities-doc-5.29.0-1-any.pkg.tar.zst: usr/share/c++utilities/api-doc/html/search/all_2.js <==
var searchData=
[
  ['background_0',['Background',['../namespaceCppUtilities_1_1EscapeCodes.html#af5b0287bad7e1a978c23f70823b60e98aa9ded1e5ce5d75814730bb4caaf49419',1,'CppUtilities::EscapeCodes']]],
  ['backward_1',['Backward',['../namespaceCppUtilities_1_1EscapeCodes.html#a1c19c2e25cb5be89569800928bafc1beab3263eb38f8903efc271cc7a760da510',1,'CppUtilities::EscapeCodes']]],
  ['bar_2',['Bar',['../namespaceFlagEnumTests.html#aab5aab542a6a9e44b7062dcd80f4f41daddc35f88fa71b6ef142ae61f35364653',1,'FlagEnumTests']]],
  ['baz_3',['Baz',['../namespaceFlagEnumTests.html#aab5aab542a6a9e44b7062dcd80f4f41daf8dce67f2c94388282ed3fa797968a7c',1,'FlagEnumTests']]],
  ['be_20set_20in_20project_20file_4',['Variables to be set in project file',['../md_doc_2buildvariables.html#autotoc_md40',1,'']]],
  ['binaryconversion_2eh_5',['binaryconversion.h',['../binaryconversion_8h.html',1,'']]],
  ['binaryconversionprivate_2eh_6',['binaryconversionprivate.h',['../binaryconversionprivate_8h.html',1,'']]],
  ['binaryreader_7',['BinaryReader',['../classCppUtilities_1_1BinaryReader.html',1,'CppUtilities::BinaryReader'],['../classCppUtilities_1_1BinaryReader.html#a8f270ec13eebce807750a3dfe610c979',1,'CppUtilities::BinaryReader::BinaryReader(std::istream *stream, bool giveOwnership=false)'],['../classCppUtilities_1_1BinaryReader.html#a3fe438a52c2ee95fdb1733abdfced1e3',1,'CppUtilities::BinaryReader::BinaryReader(const BinaryReader &amp;other)']]],
  ['binaryreader_2ecpp_8',['binaryreader.cpp',['../binaryreader_8cpp.html',1,'']]],
  ['binaryreader_2eh_9',['binaryreader.h',['../binaryreader_8h.html',1,'']]],
  ['binarywriter_10',['BinaryWriter',['../classCppUtilities_1_1BinaryWriter.html',1,'CppUtilities::BinaryWriter'],['../classCppUtilities_1_1BinaryWriter.html#aa3c7a6a20858019e8fab702f0649a245',1,'CppUtilities::BinaryWriter::BinaryWriter(std::ostream *stream, bool giveOwnership=false)'],['../classCppUtilities_1_1BinaryWriter.html#aae3223d5ffed93010bbec724ca912421',1,'CppUtilities::BinaryWriter::BinaryWriter(const BinaryWriter &amp;other)']]],
  ['binarywriter_2ecpp_11',['binarywriter.cpp',['../binarywriter_8cpp.html',1,'']]],
  ['binarywriter_2eh_12',['binarywriter.h',['../binarywriter_8h.html',1,'']]],
  ['bitratetostring_13',['bitrateToString',['../namespaceCppUtilities.html#ac701785a4097bf2289ca0b625e43a28a',1,'CppUtilities']]],
  ['bitreader_14',['BitReader',['../classCppUtilities_1_1BitReader.html',1,'CppUtilities::BitReader'],['../classCppUtilities_1_1BitReader.html#ab8d8c13cc5254fa17de8c9bb9549325f',1,'CppUtilities::BitReader::BitReader(const char *buffer, std::size_t bufferSize)'],['../classCppUtilities_1_1BitReader.html#aa9a18c775a7d6327603d42e90324bd35',1,'CppUtilities::BitReader::BitReader(const char *buffer, const char *end)']]],
  ['bitreader_2ecpp_15',['bitreader.cpp',['../bitreader_8cpp.html',1,'']]],
  ['bitreader_2eh_16',['bitreader.h',['../bitreader_8h.html',1,'']]],
  ['bitsavailable_17',['bitsAvailable',['../classCppUtilities_1_1BitReader.html#a96d35e8f444b23a4b50cb3778920ba1e',1,'CppUtilities::BitReader']]],
  ['biz_18',['Biz',['../namespaceFlagEnumTests.html#aab5aab542a6a9e44b7062dcd80f4f41da9e2136cb312356af85b09c1c30d07abb',1,'FlagEnumTests']]],
  ['black_19',['Black',['../namespaceCppUtilities_1_1EscapeCodes.html#a05ca8928629b666462897da06a5f1de4ae90dfb84e30edf611e326eeb04d680de',1,'CppUtilities::EscapeCodes']]],
  ['blink_20',['Blink',['../namespaceCppUtilities_1_1EscapeCodes.html#a144bab295e8b7e1e23dcb01fc0586f7bacfad0a7419f44ea0c64db24197abbf70',1,'CppUtilities::EscapeCodes']]],
  ['blue_21',['Blue',['../namespaceCppUtilities_1_1EscapeCodes.html#a05ca8928629b666462897da06a5f1de4a9594eec95be70e7b1710f730fdda33d9',1,'CppUtilities::EscapeCodes']]],
  ['bold_22',['Bold',['../namespaceCppUtilities_1_1EscapeCodes.html#a144bab295e8b7e1e23dcb01fc0586f7ba114c3050111d8b8ddd830b99ccebd246',1,'CppUtilities::EscapeCodes']]],
  ['bool_23',['Bool',['../structCppUtilities_1_1Traits_1_1Bool.html',1,'CppUtilities::Traits']]],
  ['bool_3c_20false_20_3e_24',['Bool&lt; false &gt;',['../structCppUtilities_1_1Traits_1_1Bool.html',1,'CppUtilities::Traits']]],
  ['bool_3c_20iscstring_3c_20t_20_3e_3a_3avalue_7c_7cisspecializationof_3c_20t_2c_20std_3a_3abasic_5fstring_20_3e_3a_3avalue_7c_7cisspecializationof_3c_20t_2c_20std_3a_3abasic_5fstring_5fview_20_3e_3a_3avalue_20_3e_25',['Bool&lt; IsCString&lt; T &gt;::value||IsSpecializationOf&lt; T, std::basic_string &gt;::value||IsSpecializationOf&lt; T, std::basic_string_view &gt;::value &gt;',['../structCppUtilities_1_1Traits_1_1Bool.html',1,'CppUtilities::Traits']]],
  ['bool_3c_20std_3a_3ais_5fsame_3c_20char_20const_20_2a_2c_20std_3a_3adecay_3c_20t_20_3e_3a_3atype_20_3e_3a_3avalue_7c_7cstd_3a_3ais_5fsame_3c_20char_20_2a_2c_20std_3a_3adecay_3c_20t_20_3e_3a_3atype_20_3e_3a_3avalue_20_3e_26',['Bool&lt; std::is_same&lt; char const *, std::decay&lt; T &gt;::type &gt;::value||std::is_same&lt; char *, std::decay&lt; T &gt;::type &gt;::value &gt;',['../structCppUtilities_1_1Traits_1_1Bool.html',1,'CppUtilities::Traits']]],
  ['bool_3c_20true_20_3e_27',['Bool&lt; true &gt;',['../structCppUtilities_1_1Traits_1_1Bool.html',1,'CppUtilities::Traits']]],
  ['bool_3c_21t_3a_3avalue_20_3e_28',['Bool&lt;!T::value &gt;',['../structCppUtilities_1_1Traits_1_1Bool.html',1,'CppUtilities::Traits']]],
  ['buffer_29',['buffer',['../classCppUtilities_1_1CopyHelper.html#a10f575981bd9a174234914cd7d96f95e',1,'CppUtilities::CopyHelper::buffer()'],['../classCppUtilities_1_1MultiArray.html#ae411ee041bfa7bc060ddf9d442a4020c',1,'CppUtilities::MultiArray::buffer()']]],
  ['buffersearch_30',['BufferSearch',['../classCppUtilities_1_1BufferSearch.html',1,'CppUtilities::BufferSearch'],['../classCppUtilities_1_1BufferSearch.html#ad155ed0a9ed9bbc583dd3f0ba7119bc8',1,'CppUtilities::BufferSearch::BufferSearch()']]],
  ['buffersearch_2ecpp_31',['buffersearch.cpp',['../buffersearch_8cpp.html',1,'']]],
  ['buffersearch_2eh_32',['buffersearch.h',['../buffersearch_8h.html',1,'']]],
  ['buffertonumber_33',['bufferToNumber',['../namespaceCppUtilities.html#af612eadff755305a2b71e61ef4399f6e',1,'CppUtilities::bufferToNumber(const CharType *string, std::size_t size, BaseType base=10)'],['../namespaceCppUtilities.html#af612eadff755305a2b71e61ef4399f6e',1,'CppUtilities::bufferToNumber(const CharType *string, std::size_t size, BaseType base=10)']]],
  ['build_34',['How to build',['../index.html#autotoc_md7',1,'']]],
  ['build_20instructions_35',['Build instructions',['../index.html#autotoc_md3',1,'']]],
  ['build_20only_20dependencies_36',['Build-only dependencies',['../index.html#autotoc_md5',1,'']]],
  ['build_20system_37',['Build system',['../md_doc_2buildvariables.html',1,'']]],
  ['build_20variables_38',['Additional build variables',['../md_doc_2buildvariables.html#autotoc_md43',1,'']]],
  ['building_20and_20debugging_39',['Building and debugging',['../index.html#autotoc_md14',1,'']]],
  ['building_20for_20android_40',['Remarks about building for Android',['../index.html#autotoc_md18',1,'']]],
  ['building_20on_20windows_41',['Remarks for building on Windows',['../index.html#autotoc_md23',1,'']]],
  ['building_20under_20windows_20for_20android_42',['Building under Windows for Android',['../index.html#autotoc_md25',1,'']]],
  ['building_20with_20msvc_43',['Building with MSVC',['../index.html#autotoc_md24',1,'']]],
  ['builds_44',['Development builds',['../index.html#autotoc_md11',1,'']]],
  ['buildvariables_2emd_45',['buildvariables.md',['../buildvariables_8md.html',1,'']]],
  ['by_20cmake_20itself_46',['Useful variables provided by CMake itself',['../md_doc_2buildvariables.html#autotoc_md34',1,'']]]
];

==> c%2B%2Butilities-doc-5.32.1-1-any.pkg.tar.zst: usr/share/c++utilities/api-doc/html/search/all_2.js <==
var searchData=
[
  ['background_0',['Background',['../namespaceCppUtilities_1_1EscapeCodes.html#af5b0287bad7e1a978c23f70823b60e98aa9ded1e5ce5d75814730bb4caaf49419',1,'CppUtilities::EscapeCodes']]],
  ['backward_1',['Backward',['../namespaceCppUtilities_1_1EscapeCodes.html#a1c19c2e25cb5be89569800928bafc1beab3263eb38f8903efc271cc7a760da510',1,'CppUtilities::EscapeCodes']]],
  ['bar_2',['Bar',['../namespaceFlagEnumTests.html#aab5aab542a6a9e44b7062dcd80f4f41daddc35f88fa71b6ef142ae61f35364653',1,'FlagEnumTests']]],
  ['baz_3',['Baz',['../namespaceFlagEnumTests.html#aab5aab542a6a9e44b7062dcd80f4f41daf8dce67f2c94388282ed3fa797968a7c',1,'FlagEnumTests']]],
  ['be_20set_20in_20the_20project_20file_4',['Variables to be set in the project file',['../md_doc_2buildvariables.html#autotoc_md41',1,'']]],
  ['binaryconversion_2eh_5',['binaryconversion.h',['../binaryconversion_8h.html',1,'']]],
  ['binaryconversionprivate_2eh_6',['binaryconversionprivate.h',['../binaryconversionprivate_8h.html',1,'']]],
  ['binaryreader_7',['BinaryReader',['../classCppUtilities_1_1BinaryReader.html',1,'CppUtilities::BinaryReader'],['../classCppUtilities_1_1BinaryReader.html#a8f270ec13eebce807750a3dfe610c979',1,'CppUtilities::BinaryReader::BinaryReader(std::istream *stream, bool giveOwnership=false)'],['../classCppUtilities_1_1BinaryReader.html#a3fe438a52c2ee95fdb1733abdfced1e3',1,'CppUtilities::BinaryReader::BinaryReader(const BinaryReader &amp;other)']]],
  ['binaryreader_2ecpp_8',['binaryreader.cpp',['../binaryreader_8cpp.html',1,'']]],
  ['binaryreader_2eh_9',['binaryreader.h',['../binaryreader_8h.html',1,'']]],
  ['binarywriter_10',['BinaryWriter',['../classCppUtilities_1_1BinaryWriter.html',1,'CppUtilities::BinaryWriter'],['../classCppUtilities_1_1BinaryWriter.html#aa3c7a6a20858019e8fab702f0649a245',1,'CppUtilities::BinaryWriter::BinaryWriter(std::ostream *stream, bool giveOwnership=false)'],['../classCppUtilities_1_1BinaryWriter.html#aae3223d5ffed93010bbec724ca912421',1,'CppUtilities::BinaryWriter::BinaryWriter(const BinaryWriter &amp;other)']]],
  ['binarywriter_2ecpp_11',['binarywriter.cpp',['../binarywriter_8cpp.html',1,'']]],
  ['binarywriter_2eh_12',['binarywriter.h',['../binarywriter_8h.html',1,'']]],
  ['bitratetostring_13',['bitrateToString',['../namespaceCppUtilities.html#ac701785a4097bf2289ca0b625e43a28a',1,'CppUtilities']]],
  ['bitreader_14',['BitReader',['../classCppUtilities_1_1BitReader.html',1,'CppUtilities::BitReader'],['../classCppUtilities_1_1BitReader.html#ab8d8c13cc5254fa17de8c9bb9549325f',1,'CppUtilities::BitReader::BitReader(const char *buffer, std::size_t bufferSize)'],['../classCppUtilities_1_1BitReader.html#aa9a18c775a7d6327603d42e90324bd35',1,'CppUtilities::BitReader::BitReader(const char *buffer, const char *end)']]],
  ['bitreader_2ecpp_15',['bitreader.cpp',['../bitreader_8cpp.html',1,'']]],
  ['bitreader_2eh_16',['bitreader.h',['../bitreader_8h.html',1,'']]],
  ['bitsavailable_17',['bitsAvailable',['../classCppUtilities_1_1BitReader.html#a96d35e8f444b23a4b50cb3778920ba1e',1,'CppUtilities::BitReader']]],
  ['biz_18',['Biz',['../namespaceFlagEnumTests.html#aab5aab542a6a9e44b7062dcd80f4f41da9e2136cb312356af85b09c1c30d07abb',1,'FlagEnumTests']]],
  ['black_19',['Black',['../namespaceCppUtilities_1_1EscapeCodes.html#a05ca8928629b666462897da06a5f1de4ae90dfb84e30edf611e326eeb04d680de',1,'CppUtilities::EscapeCodes']]],
  ['blink_20',['Blink',['../namespaceCppUtilities_1_1EscapeCodes.html#a144bab295e8b7e1e23dcb01fc0586f7bacfad0a7419f44ea0c64db24197abbf70',1,'CppUtilities::EscapeCodes']]],
  ['blue_21',['Blue',['../namespaceCppUtilities_1_1EscapeCodes.html#a05ca8928629b666462897da06a5f1de4a9594eec95be70e7b1710f730fdda33d9',1,'CppUtilities::EscapeCodes']]],
  ['bold_22',['Bold',['../namespaceCppUtilities_1_1EscapeCodes.html#a144bab295e8b7e1e23dcb01fc0586f7ba114c3050111d8b8ddd830b99ccebd246',1,'CppUtilities::EscapeCodes']]],
  ['bool_23',['Bool',['../structCppUtilities_1_1Traits_1_1Bool.html',1,'CppUtilities::Traits']]],
  ['bool_3c_20false_20_3e_24',['Bool&lt; false &gt;',['../structCppUtilities_1_1Traits_1_1Bool.html',1,'CppUtilities::Traits']]],
  ['bool_3c_20iscstring_3c_20t_20_3e_3a_3avalue_7c_7cisspecializationof_3c_20t_2c_20std_3a_3abasic_5fstring_20_3e_3a_3avalue_7c_7cisspecializationof_3c_20t_2c_20std_3a_3abasic_5fstring_5fview_20_3e_3a_3avalue_20_3e_25',['Bool&lt; IsCString&lt; T &gt;::value||IsSpecializationOf&lt; T, std::basic_string &gt;::value||IsSpecializationOf&lt; T, std::basic_string_view &gt;::value &gt;',['../structCppUtilities_1_1Traits_1_1Bool.html',1,'CppUtilities::Traits']]],
  ['bool_3c_20std_3a_3ais_5fsame_3c_20char_20const_20_2a_2c_20std_3a_3adecay_3c_20t_20_3e_3a_3atype_20_3e_3a_3avalue_7c_7cstd_3a_3ais_5fsame_3c_20char_20_2a_2c_20std_3a_3adecay_3c_20t_20_3e_3a_3atype_20_3e_3a_3avalue_20_3e_26',['Bool&lt; std::is_same&lt; char const *, std::decay&lt; T &gt;::type &gt;::value||std::is_same&lt; char *, std::decay&lt; T &gt;::type &gt;::value &gt;',['../structCppUtilities_1_1Traits_1_1Bool.html',1,'CppUtilities::Traits']]],
  ['bool_3c_20true_20_3e_27',['Bool&lt; true &gt;',['../structCppUtilities_1_1Traits_1_1Bool.html',1,'CppUtilities::Traits']]],
  ['bool_3c_21t_3a_3avalue_20_3e_28',['Bool&lt;!T::value &gt;',['../structCppUtilities_1_1Traits_1_1Bool.html',1,'CppUtilities::Traits']]],
  ['buffer_29',['buffer',['../classCppUtilities_1_1CopyHelper.html#a10f575981bd9a174234914cd7d96f95e',1,'CppUtilities::CopyHelper::buffer()'],['../classCppUtilities_1_1MultiArray.html#ae411ee041bfa7bc060ddf9d442a4020c',1,'CppUtilities::MultiArray::buffer()']]],
  ['buffersearch_30',['BufferSearch',['../classCppUtilities_1_1BufferSearch.html',1,'CppUtilities::BufferSearch'],['../classCppUtilities_1_1BufferSearch.html#ad155ed0a9ed9bbc583dd3f0ba7119bc8',1,'CppUtilities::BufferSearch::BufferSearch()']]],
  ['buffersearch_2ecpp_31',['buffersearch.cpp',['../buffersearch_8cpp.html',1,'']]],
  ['buffersearch_2eh_32',['buffersearch.h',['../buffersearch_8h.html',1,'']]],
  ['buffertonumber_33',['bufferToNumber',['../namespaceCppUtilities.html#af612eadff755305a2b71e61ef4399f6e',1,'CppUtilities::bufferToNumber(const CharType *string, std::size_t size, BaseType base=10)'],['../namespaceCppUtilities.html#af612eadff755305a2b71e61ef4399f6e',1,'CppUtilities::bufferToNumber(const CharType *string, std::size_t size, BaseType base=10)']]],
  ['build_34',['How to build',['../index.html#autotoc_md7',1,'']]],
  ['build_20instructions_35',['Build instructions',['../index.html#autotoc_md3',1,'']]],
  ['build_20only_20dependencies_36',['Build-only dependencies',['../index.html#autotoc_md5',1,'']]],
  ['build_20system_37',['Build system',['../md_doc_2buildvariables.html',1,'']]],
  ['build_20variables_38',['Additional build variables',['../md_doc_2buildvariables.html#autotoc_md44',1,'']]],
  ['building_20and_20debugging_39',['Building and debugging',['../index.html#autotoc_md14',1,'']]],
  ['building_20for_20android_40',['Remarks about building for Android',['../index.html#autotoc_md18',1,'']]],
  ['building_20on_20windows_41',['Remarks for building on Windows',['../index.html#autotoc_md24',1,'']]],
  ['building_20under_20windows_20for_20android_42',['Building under Windows for Android',['../index.html#autotoc_md26',1,'']]],
  ['building_20with_20msvc_43',['Building with MSVC',['../index.html#autotoc_md25',1,'']]],
  ['builds_44',['Development builds',['../index.html#autotoc_md11',1,'']]],
  ['buildvariables_2emd_45',['buildvariables.md',['../buildvariables_8md.html',1,'']]],
  ['by_20cmake_20itself_46',['Useful variables provided by CMake itself',['../md_doc_2buildvariables.html#autotoc_md35',1,'']]]
];
